#!/usr/bin/env node
import { join, basename, resolve } from 'node:path';
import React from 'react';
import { render } from 'ink';
import meow from 'meow';
import fastGlob from 'fast-glob';
import fs from 'fs-extra';
import { execa } from 'execa';
import App from './App.js';
const interfaces = new Map();
const targets = await fastGlob.glob(join('./commands', '**/*.js'));
for (const interfacePath of targets) {
  const name = basename(interfacePath, '.js');
  interfaces.set(name.toLowerCase(), await import(resolve(interfacePath)));
}
const scripts = new Map();
const pack = await fs.readJson('../package.json');
for (const [name, command] of Object.entries(pack.scripts)) {
  const split = name.split(':');
  const prefix = split.shift();
  if (prefix === 'command') {
    scripts.set(split.shift(), ['run', name]);
  }
}
const cli = meow(`
		Usage
		  $ bulldog <command>

		Examples
		  $ bulldog search
		  <search interface displayed>
	`, {
  importMeta: import.meta
});
const {
  input
} = cli;
if (scripts.has(input[0])) {
  const args = scripts.get(input[0]);
  const subProcess = execa('npm', args, {
    stdio: 'inherit',
    shell: true
  });
  subProcess.on('error', error => {
    console.error(error.message);
  });
} else {
  render( /*#__PURE__*/React.createElement(App, {
    commands: input,
    interfaces: interfaces
  }));
}